#
Benchopt results: QR

Last updated: 2023-10-14 22:48 with 1 result files in total.

Results | Datasets | System info |
--- | --- | --- | ---
QR 2023-10-14 22h48m25 | Reg_data dataset_name=liver-disorders dataset_name=kin8nm dataset_name=house_8L dataset_name=topo_2_1 dataset_name=Buzzinsocialmedia_Twitter | CPU: 4 RAM (GB): 31 CUDA: NVIDIA GeForce RTX 4090: cuda_12.2 platform: Linux6.2.0-34-generic-x86_64 processor: 13th Gen Intel(R) Core(TM) i9-13900K |

dialog text